You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by st...@apache.org on 2016/11/18 18:57:50 UTC

svn commit: r1770425 - in /subversion/branches/authzperf: subversion/mod_authz_svn/mod_authz_svn.c tools/server-side/svnauthz.c

Author: stefan2
Date: Fri Nov 18 18:57:50 2016
New Revision: 1770425

URL: http://svn.apache.org/viewvc?rev=1770425&view=rev
Log:
On the authzperf branch:
Update references to svn_repos_authz_read to the lastest API version.

* subversion/mod_authz_svn/mod_authz_svn.c
  (canonicalize_access_file): Update commentary.
  (get_access_conf): We don't have a repos we can use here but that
                     is fine ...

* tools/server-side/svnauthz.c
  (get_authz): Same.

Modified:
    subversion/branches/authzperf/subversion/mod_authz_svn/mod_authz_svn.c
    subversion/branches/authzperf/tools/server-side/svnauthz.c

Modified: subversion/branches/authzperf/subversion/mod_authz_svn/mod_authz_svn.c
URL: http://svn.apache.org/viewvc/subversion/branches/authzperf/subversion/mod_authz_svn/mod_authz_svn.c?rev=1770425&r1=1770424&r2=1770425&view=diff
==============================================================================
--- subversion/branches/authzperf/tools/server-side/svnauthz.c (original)
+++ subversion/branches/authzperf/tools/server-side/svnauthz.c Fri Nov 18 18:57:50 2016
@@ -275,9 +275,9 @@ get_authz(svn_authz_t **authz, struct sv
                               opt_state->txn, pool);
 
   /* Else */
-  return svn_repos_authz_read2(authz, opt_state->authz_file,
+  return svn_repos_authz_read3(authz, opt_state->authz_file,
                                opt_state->groups_file,
-                               TRUE, pool);
+                               TRUE, NULL, pool, pool);
 }
 
 static svn_error_t *
--- subversion/branches/authzperf/subversion/mod_authz_svn/mod_authz_svn.c (original)
+++ subversion/branches/authzperf/subversion/mod_authz_svn/mod_authz_svn.c Fri Nov 18 18:57:50 2016
@@ -154,7 +154,7 @@ canonicalize_access_file(const char *acc
     }
 
   /* We don't canonicalize repos relative urls since they get
    * canonicalized before calling svn_repos_authz_read2() when they
    * are resolved. */
 
   return access_file;
@@ -472,10 +472,10 @@ get_access_conf(request_rec *r, authz_sv
   access_conf = user_data;
   if (access_conf == NULL)
     {
-
-      svn_err = svn_repos_authz_read2(&access_conf, access_file,
-                                      groups_file, TRUE,
-                                      r->connection->pool);
+      svn_err = svn_repos_authz_read3(&access_conf, access_file,
+                                      groups_file, TRUE, NULL,
+                                      r->connection->pool,
+                                      scratch_pool);
 
       if (svn_err)
         {
@@ -154,7 +154,7 @@ canonicalize_access_file(const char *acc
 
   /* We don't canonicalize repos relative urls since they get
-   * canonicalized before calling svn_repos_authz_read2() when they
+   * canonicalized before calling svn_repos_authz_read3() when they
    * are resolved. */
 

Modified: subversion/branches/authzperf/tools/server-side/svnauthz.c
URL: http://svn.apache.org/viewvc/subversion/branches/authzperf/tools/server-side/svnauthz.c?rev=1770425&r1=1770424&r2=1770425&view=diff
==============================================================================